@@ -18,7 +18,7 @@ use Exporter qw(import);
 
 @EXPORT_OK = qw(get_Z get_symbol get_name);
 @EXPORT    = qw();
-$VERSION   = '1.062';
+$VERSION   = '1.063';
 
 use subs qw(
 	_get_name_by_Z
@@ -181,12 +181,12 @@ $Default_language = $Languages{'English'};
 110 => [ qw( Armstadtiumdai Darmstadtium ) ],
 111 => [ qw( Oentgeniumrai Roentgenium ) ],
 112 => [ qw( Operniciumcai Copernicium ) ],
-113 => [ qw( Nuntriumuai Ununtrium ) ],
+113 => [ qw( Ihoniumnai Nihonium ) ],  # Nihonium (Nh)
 114 => [ qw( Leroviumfai Flerovium ) ],
-115 => [ qw( Nunpentiumuai Ununpentium ) ],
+115 => [ qw( Oscoviummai Moscovium ) ], # Moscovium (Mc)
 116 => [ qw( Ivermoriumlai Livermorium ) ],
-117 => [ qw( Nunseptiumuai Ununseptium ) ],
-118 => [ qw( Nunoctiumuai Ununoctium ) ],
+117 => [ qw( Ennessinetai Tennessine ) ], # Tennessine (Ts)
+118 => [ qw( Ganessonoai Oganesson ) ], # Oganesson (Og)
 );
 
 {
